@@ -204,7 +204,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         :return: created AssetRelation class instance
         """
         response = self._put(
-            f'{self._catalog_api_base}/asset-relation',
+            f'{self._catalog_api_base}/asset-relations',
             payload=asset_relation
         )
         return AssetRelation(**response['data'])
@@ -407,10 +407,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         if _HEADERS['accessKey'] is None:
             _HEADERS['accessKey'] = self.access_key
         if _HEADERS['secretKey'] is None:
-            _HEADERS['secretKey'] = self.access_key
-        self.logger.info(
-            f" HEADERS {_HEADERS} "
-        )
+            _HEADERS['secretKey'] = self.secret_key
         response = requests.post(
             url=url, headers=_HEADERS, json=payload, timeout=self._timeout, verify=False
         )
@@ -427,10 +424,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         if _HEADERS['accessKey'] is None:
             _HEADERS['accessKey'] = self.access_key
         if _HEADERS['secretKey'] is None:
-            _HEADERS['secretKey'] = self.access_key
-        self.logger.info(
-            f" HEADERS {_HEADERS} "
-        )
+            _HEADERS['secretKey'] = self.secret_key
         response = requests.put(
             url=url, headers=_HEADERS, json=payload, timeout=self._timeout, verify=False
         )
@@ -447,10 +441,7 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         if _HEADERS['accessKey'] is None:
             _HEADERS['accessKey'] = self.access_key
         if _HEADERS['secretKey'] is None:
-            _HEADERS['secretKey'] = self.access_key
-        self.logger.info(
-            f" HEADERS {_HEADERS} "
-        )
+            _HEADERS['secretKey'] = self.secret_key
         response = requests.get(
             url=url, params=params, headers=_HEADERS, timeout=self._timeout, verify=False
         )
